{% macro fav(link) %}
    {{ (settings['brand']['favicon_folder'] + link)|static }}
{% endmacro %}
{% macro categories(in_list) %}{% for cat in in_list %}"{{ cat }}"{% if loop.last == False %},{% endif %}
{% endfor %}{% endmacro %}
{
"$schema": "https://json.schemastore.org/web-manifest-combined.json",
"name": "{{ settings['brand']['app_name'] }}",
"short_name": "{{ settings['brand']['short_name'] }}",
"categories": [{{ categories(settings['brand']['meta']['categories']) }}],
"start_url": ".",
"theme_color": "{{ settings['brand']['meta']['theme_color'] }}",
"background_color": "{{ settings['brand']['meta']['bg_color'] }}",
"lang": "en-US",
"description": "{{ settings['brand']['meta']['description'] }}",
"icons": [
{
"src": "{{ fav("android-icon-36x36.png") }}",
"sizes": "36x36",
"type": "image/png",
"density": "0.75"
},
{
"src": "{{ fav("android-icon-48x48.png") }}",
"sizes": "48x48",
"type": "image/png",
"density": "1.0"
},
{
"src": "{{ fav("android-icon-72x72.png") }}",
"sizes": "72x72",
"type": "image/png",
"density": "1.5"
},
{
"src": "{{ fav("android-icon-96x96.png") }}",
"sizes": "96x96",
"type": "image/png",
"density": "2.0"
},
{
"src": "{{ fav("android-icon-144x144.png") }}",
"sizes": "144x144",
"type": "image/png",
"density": "3.0"
},
{
"src": "{{ fav("android-icon-192x192.png") }}",
"sizes": "192x192",
"type": "image/png",
"density": "4.0"
}
]
}