from menagerie.generate import generate
from menagerie.new_project import new_project

__version__ = '0.0.9'
__help__ = """
                Usage:
                    menagerie new-project [name] : Creates a new menagerie project with a given name
                    menagerie generate [--config=...] : Generates a site with the given config
                    menagerie help : Shows this message
                    menagerie version : Shows the version
            """
